Author: Degli Esposti, Davide
Description: The liver is one of the richest organs in terms of number and density of mitochondria. Most chronic liver diseases are associated with the accumulation of damaged mitochondria. Hepatic mitochondria have unique features compared to other organs' mitochondria, since they are the hub that integrates hepatic metabolism of carbohydrates, lipids and proteins. Mitochondria are also essential in hepatocyte survival as mediator of apoptosis and necrosis. Hepatocytes have developed different mechanisms to keep mitochondrial integrity or to prevent the effects of mitochondrial lesions, in particular regulating organelle biogenesis and degradation. In this paper, we will focus on the role of mitochondria in liver physiology, such as hepatic metabolism, reactive oxygen species homeostasis and cell survival. We will also focus on chronic liver pathologies, especially those linked to alcohol, virus, drugs or metabolic syndrome and we will discuss how mitochondria could provide a promising therapeutic [cell cut: 1026 characters, first 1000 kept]
Date: 2012/06/15

Hindawi Publishing Corporation

- Home
- Journals
- About Us

Biochemistry Research International

Journal Menu

- About this Journal
- Abstracting and Indexing
- Aims and Scope
- Article Processing Charges
- Articles in Press
- Author Guidelines
- Bibliographic Information
- Citations to this Journal
- Contact Information
- Editorial Board
- Editorial Workflow
- Free eTOC Alerts
- Publication Ethics
- Reviewers Acknowledgment
- Submit a Manuscript
- Subscription Information
- Table of Contents

- Open Special Issues
- Published Special Issues
- Special Issue Guidelines

- Abstract
- Full-Text PDF
- Full-Text HTML
- Full-Text ePUB
- Linked References
- How to Cite this Article
- Complete Special Issue

    Biochemistry Research International
    Volume 2012 (2012), Article ID 387626, 16 pages
    doi:10.1155/2012/387626

Review Article

## Mitochondrial Roles and Cytoprotection in Chronic Liver Injury

Davide Degli Esposti,1,2 Jocelyne Hamelin,1,2 Nelly Bosselut,1,2 Raphaël Saffroy,1,2 Mylène Sebagh,3 Alban Pommier,1,2 Cécile Martel,2 and Antoinette Lemoine1,2,4

1AP-HP, Hôpital Paul Brousse, Service de Biochimie et Biologie Moléculaire, 14 Avenue Paul Vaillant Couturier, 94804 Villejuif Cedex, France
2Inserm U1004, Université Paris 11, Institut André Lwoff, PRES Universud-Paris, Institut du Foie/Liver Institute, 14 Avenue Paul Vaillant Couturier, 94804 Villejuif, France
3AP-HP, Inserm U785, Hôpital Paul Brousse, Service d’Anatomie Pathologique, 14 Avenue Paul Vaillant Couturier, 94804 Villejuif Cedex, France
4Université Paris Sud 11, Faculté de Pharmacie, 5 rue Jean-Baptiste Clément, 92296 Châtenay-Malabry Cedex, France

Received 11 January 2012; Revised 20 March 2012; Accepted 11 April 2012

Academic Editor: Etienne Jacotot

Copyright © 2012 Davide Degli Esposti et al. This is an open access article distributed under the Creative Commons Attribution License, which permits unrestricted use, distribution, and reproduction in any medium, provided the original work is properly cited.

#### Abstract

The liver is one of the richest organs in terms of number and density of mitochondria. Most chronic liver diseases are associated with the accumulation of damaged mitochondria. Hepatic mitochondria have unique features compared to other organs' mitochondria, since they are the hub that integrates hepatic metabolism of carbohydrates, lipids and proteins. Mitochondria are also essential in hepatocyte survival as mediator of apoptosis and necrosis. Hepatocytes have developed different mechanisms to keep mitochondrial integrity or to prevent the effects of mitochondrial lesions, in particular regulating organelle biogenesis and degradation. In this paper, we will focus on the role of mitochondria in liver physiology, such as hepatic metabolism, reactive oxygen species homeostasis and cell survival. We will also focus on chronic liver pathologies, especially those linked to alcohol, virus, drugs or metabolic syndrome and we will discuss how mitochondria could provide a promising therapeutic target in these contexts.

#### 1. Introduction

Mitochondria are intracellular double membrane-bound structures that provide energy (ATP) for intracellular metabolism. The intramitochondrial metabolism includes Krebs cycle and beta-oxidation. Mitochondria are also essential for assembly of iron sulfur clusters and regulation of calcium homeostasis. However, mitochondria are not only the cell’s powerhouse, organelles whose particular architecture and biochemical composition enable the maximization of energy production by oxidative phosphorylation (OXPHOS), but they also have a second crucial function, namely, the control of cell death following activation of intracellular signaling cascades or death receptor-mediated pathways [1]. Indeed, the mitochondrial membrane permeabilization (MMP) is the decisive event that marks the transition from survival to death. Thus, mitochondrial membranes integrate proapoptotic and antiapoptotic signals coming from microenvironment or from other intracellular organelles, such as endoplasmic reticulum or lysosomes, defining the ultimate cell fate [1, 2]. The number and functions of mitochondria can vary depending on age, sex, organ, and physiological or pathological conditions that are still unknown [3–5].

Mitochondrial dysfunctions are frequently described as early and initiating events in various chronic pathological conditions in different tissues and organs, such as liver, brain, or heart [6–8]. Most forms of chronic liver diseases are associated with the accumulation of damaged mitochondria responsible for abnormal reactive oxygen species (ROS) formation, glutathione (GSH) depletion, protein alkylation, and respiratory complex alterations. Depending on their nature and severity, the mitochondrial alterations may induce lipid accumulation, apoptosis, and/or necrosis leading to hepatic cytolysis and inflammation. These pathological events can correspond to different clinical features, such as lactacidosis, hypoglycemia, elevated serum transaminases, higher conjugated bilirubinemia, and hyperammonemia. However, a growing body of literature has also shown that demised cells with damaged mitochondria can develop cytoprotective mechanisms to ensure cellular energy homeostasis and limit cell death [9–12]. These mechanisms consist in both activation of intracellular pathways targeting mitochondria function and intercellular and interorgan signaling to coordinate adaptive metabolic responses within the organism as a whole. The regulation of the mitochondrial biogenesis and/or turnover (by general autophagy or specific mitochondria-targeted mitophagy) plays an important role in the balance of cell survival and cell death [13]. This balance is importantly linked to the energy metabolism homeostasis, in particular with ATP synthesis, as it has been reported in some chronic liver pathologies, such as steatosis and nonalcoholic steatohepatitis (NASH) [14].

In this paper, we will focus on the role of mitochondria in liver physiology and pathologies, especially those linked to alcohol, virus, drugs, or metabolic syndrome and we will discuss how mitochondria could provide a promising therapeutic target in these contexts.

#### 2. Mitochondria in Liver Physiology

The liver is one of the richest organs in terms of number and density of mitochondria. The density of mitochondria is different in various tissues depending upon numerous factors, mostly the demands of oxidative phosphorylation. A study showed that in nontumorous liver tissue the copy number of mitochondrial DNA (mtDNA) in male patients affected by hepatocellular carcinoma (HCC) was lower than that of the female patients (
versus
) [4]. Since each mitochondrion can host from two to ten copies of mtDNA [5], we can assume that in the liver, the number of mitochondria could range from 500 to 4000 per hepatocyte.

In this chapter, we will review the role of mitochondria in hepatic metabolism, reactive oxygen species (ROS) homeostasis, and cell death regulation.

##### 2.1. Mitochondria Are Essential in the Hepatic Metabolism

The liver is an essential life organ in all mammals and plays a central role in the homeostasis of carbohydrate, lipid, and protein metabolism of the organism. The liver is a main target of insulin and glucagon signaling and contributes to balancing glucose blood levels by regulating glycogen synthesis and gluconeogenesis in hepatocytes [15]. It is also a key organ in maintaining lipid homeostasis: it is the main site of fatty acid oxidation together with the muscle (mainly
-oxidation taking place into the mitochondria) and it is the sole organ able to synthesize fatty acids by de novo lipogenesis [16]. Finally, the liver is a key regulator of protein metabolism for the entire organism as hepatocytes synthesize essential proteins such as albumin and lipoproteins and allow ammonia detoxification through the urea cycle [17].

In this context, the mitochondria provide the hub that integrates these pathways, serving as a critical site for the production and exchange of metabolic intermediates (Figure 1). It plays a critical role in orchestrating these complex metabolic networks in order to maintain proper homeostasis.

Figure 1: The role of hepatocyte mitochondria in liver metabolism. The liver is a central organ for the homeostasis of carbohydrates, lipids and proteins metabolism. In this context, hepatocyte mitochondria are essential in regulating the flux of metabolites in the cell in order to adjust energetic demand, ammonia detoxification, or anabolic pathways. Energy demand is met by complete oxidation of acetyl groups coming from glycolysis through tricarboxyilic acid cycle or of acyl groups coming from lipolysis through
-oxidation. Moreover, mitochondria are a unique site for metabolizing ammonia into the less toxic urea. Then, mitochondria provide shuttle proteins that allow specific addressing to anabolic pathways, as in the case of citrate transport protein (CTP) (see text for details).

Mitochondria are largely involved in glucose metabolism, as the pyruvate dehydrogenase (PDH) complex is expressed in the mitochondrial matrix. It is composed by 5 subunits (pyruvate dehydrogenase, E1 alpha and E1 beta; dihydrolipoamide S-acetyl transferase, E2; and lipoamide dehydrogenase, E3 and E3BP). It catalyzes the conversion of pyruvate, the last metabolite of aerobic glycolysis, to Acetyl-CoA and CO2. In the last ten years evidence has accumulated showing an important involvement of liver mitochondria in insulin resistance. In insulin resistant states, alterations in mitochondrial function, structure, and organization have been described [18]. In particular, a decrease in respiration and ATP production has been frequently described and the decreased efficiency is often attributed to excessive mitochondrial ROS production inducing respiratory chain protein oxidation [14, 18, 19].

Concerning lipid metabolism, few mitochondrial proteins play key roles in catabolism as well as in anabolism. The carnitine palmityl transferases I and II (CPT I-II) are expressed at the mitochondrial outer membrane (MOM) and mitochondrial inner membrane (MIM), respectively, and are essential for acyl-CoA transport and subsequent fatty acid
-oxidation in liver and muscle. A mitochondrial transport protein, the citrate transport protein (CTP), allows acetyl-CoA to be transported from mitochondria to the cytosol in the form of citrate in order to be used as building block in hepatic de novo lipogenesis [20]. Hepatic mitochondria are essential also in protein metabolism. Nitrogen enters the liver as free ammonia and amino acids, mostly glutamine and alanine [17]. Enzymes involved in ammonia detoxification and urea synthesis (glutamate dehydrogenase, carbamoyl phosphate synthetase I and ornithine transcarbamylase) are exclusively expressed in the hepatocyte mitochondria. Indeed, the first step in the urea cycle for ammonia detoxification and disposal is located at mitochondria and mediated by the enzyme carbamoyl phosphate synthetase 1 (CPSI). CPSI is allosterically regulated by cytosolic N-acetyl-L-glutamate (NAG) [21]. Ammonia can be also converted to glutamine by the glutamine synthetase (GS) catalyzing the condensation of glutamate and ammonia and, vice versa, ammonia can be generated by glutaminase. Therefore, an increase in blood ammonia depends on the activity of the enzyme glutamine synthetase, the glutamine/glutamate cycle, and the tissue capacity to eliminate toxic ammonia. Mitochondria represent a major site of glutamine metabolism, as both glutaminase and GS are mitochondrial processes in the liver. Interestingly, in absence of glucose but with high glutamine concentrations, mitochondrial structure and dynamics change towards a more condensed configuration and extended reticulum [22]. Moreover, urea and glutamine metabolism are differently distributed in the hepatic acinus. Ammonia is taken up by periportal hepatocytes, metabolized to urea via the urea cycle and excreted through the kidneys. Any ammonia escaping detoxification is usually trapped by perivenous hepatocytes, where it is converted to glutamine via glutamine synthetase [23]. Indeed, urea synthesis enzymes and glutaminase are expressed in periportal hepatocytes, while glutamine synthetase is expressed in perivenous hepatocytes [17]. Then, the periportal region has a low affinity but a high capacity for ammonia detoxification. Hepatic GS allows ammonia scavenging, and when liver impairment is present, a diminished detoxification capacity is observed. GS has a short half-life and its activity is regulated and modulated by several mediators and hormones. The brain also uses glutamine synthesis for metabolizing ammonia and for deamination in the presynaptic terminals to produce glutamate, an important excitatory neurotransmitter. When it accumulates, it is taken up by the astrocytes and recycled back to glutamine, the “storage centre” for free ammonia [24, 25]. It is interesting to note that the different subcellular localization of GS (mitochondrial in hepatocytes and cytoplasmic in astrocytes) has been considered a partial explanation to the higher toxicity of ammonia in the brain than in the liver [26]. However, the exact role of mitochondrial dysfunctions in hyperammonemia still needs to be addressed, in particular for chronic liver disease. However, liver and mitochondria metabolism are directly involved in the homeostatic balance of brain ammonia, glutamine, and glutamate.

##### 2.2. Mitochondria Are Essential in Reactive Oxygen Species Homeostasis

Mitochondria are the intracellular organelles devolved to energy (ATP) production in all eukaryotic cells through oxidative phosphorylation (OXPHOS). OXPHOS is allowed by the four multiprotein complexes of the mitochondrial respiratory chain (MRC) and by the ATP synthase. OXPHOS physiologically produces reactive oxygen species (ROS) and in vitro estimations lead to considering that up to 2% of oxygen consumption results in superoxide anion generation [27]. Thus, mitochondria are a main source of ROS (Figure 2). ROS are produced during oxidative metabolism mainly by the complexes I, III, or IV of the electron transport chain, where electrons can prematurely reduce oxygen, resulting in the formation of superoxide radical [27–30]. In the normal state, most of the ROS generated by the MRC are detoxified by the mitochondrial antioxidant enzymes, such as SOD2/MnSOD, which convert superoxide to hydrogen peroxide, subsequently detoxified by GSH peroxidase. The remaining nondetoxified ROS diffuse out of mitochondria and serve as signaling molecules vital for normal cellular functions [31]. These physiological ROS are involved in specific cellular pathway aimed to adapt global metabolism to transient or chronic stress conditions. It is interesting to note that ATP synthase may also have a regulating role in ROS production. Actually, in the experimental model of aging provided by the fungus Podospora anserine, characterized by mitochondrial etiology of aging, the alpha subunit of ATP synthase functions as a sensor of oxidative stress and provides an intramolecular quencher (at the residue Trp503) for ROS [32]. Moreover, a recent mechanism that seems to buffer ROS excess has been described in physiological and pathological conditions. The expression of uncoupling proteins (UPCs) promotes a controlled uncoupling of proton flux from the ATP synthase and could lead to decreased ROS production [33].

Figure 2: The role of hepatocyte mitochondria in reactive oxygen species homeostasis. Mitochondria are a physiological source of reactive oxygen species (ROS). In this context, ROS exert a signaling role in cell proliferation and differentiation. However, different types of stress can target directly or indirectly hepatocyte mitochondria, such as drugs, virus, hypoxia, inflammatory cytokines, excess of
-oxidation, ectopic expression of cytochromes P450. In this case, overproduction of ROS may damage both mitochondrial and other cellular components, such as OXPHOS protein subunits, lipid membranes, mitochondrial, or nuclear DNA. These cellular lesions can favor the development of tissue lesions, such as steatohepatitis or hepatocellular carcinoma.

##### 2.3. Mitochondria Are Essential in Cell Survival

Mitochondria are the essential actor in keeping the balance between cell survival and cell death, in particular in hepatocytes, where they trigger the intrinsic pathway of apoptosis and are also involved in necrotic cell death. The regulation of membrane permeability is the main mechanism that makes the cells shift from survival to cell death. The MOM is permeable to solutes of molecular mass (MM)
6 kDa due to the presence of channels, such as the voltage-dependent anion channel (VDAC), which belongs to the porin subfamily. However, with an estimated pore diameter about 2.6–3 nm, VDAC would not allow the passage of a folded protein like cytochrome c. In contrast, the MIM is almost totally impermeable and transport of ions and solutes is granted by mitochondrial carrier proteins. Most mitochondrial proteins exhibit dual functions, a vital metabolic function, and a lethal pro-apoptotic function. This applies to various channels: voltage-dependent anion channel (VDAC), adenine nucleotide translocase (ANT), Bax, t-Bid, Bak; receptors (e.g., TOM22); chaperones (cyclophilin D, CypD), as well as oxidoreductases (apoptosis-inducing factor, AIF).

During apoptosis, many signals can converge to the mitochondrion to MMP, the rate-limiting step in the execution of the death process [1]. MMP is regulated mainly by the members of Bcl-2 family, members of the PTP complex (VDAC, ANT, CypD) and lipids [1]. Bcl-2 family is composed of pro-apoptotic proteins (e.g., Bax, Bak, Bid, Bik, Bnip3) and anti-apoptotic members (Bcl-2,
, Bcl-w, Mcl-1, A1). Pro-apoptotic proteins favor MMP by translocating to MOM and forming mega channels, mainly by oligomerization (e.g., Bax-Bak oligomers or Bax-VDAC complexes), while anti-apoptotic members stabilize MOM and tend to prevent MMP [1, 34–36]. Accumulation of modified lipids (e.g., oxidized cardiolipin, ceramide) and ions (e.g., Ca2+) in the mitochondrion can also influence MMP [37]. Moreover, the intracellular milieu, such as pH, ROS, and ATP levels can contribute to define a permissive environment for MMP execution [1]. Multiple mechanisms can mediate MMP, depending on the cell type and the death stimuli. They can affect either the MOM, or both mitochondrial membranes (MOM+MIM). In the MOM model, intermembrane space proteins are released into the cytosol by passage through large proteic/lipidic channels while, in the MOM+MIM model, intermembrane space proteins are freely released into the cytosol through the MOM ruptures. Nevertheless, these two models can coexist in conditions involving on the one hand the translocation of the truncated form of Bid (tBid) to mitochondria, and in the other hand mitochondrial Ca2+ accumulation and ROS increase, as observed in conditions of endoplasmic reticulum stress [1]. In the MOM+MIM model, the contribution of the permeability transition pore (PTP) seems to play an important role. The PTP consists of a multiprotein complex (PTPC) and various proteins are involved in its opening. Long lasting opening of PTPC increases MIM permeability and, in the presence of adequate amounts of ATP, would lead to apoptotic cell death [1]. PTPC opening is highly sensitive to Ca2+, prooxidant agents, pro-apoptotic Bcl-2 family members and some chemotherapeutics agents [38]. However, Ca2+-induced PTP opening has been also reported to induce necrotic cell death, in particular when intracellular ATP levels are too low to allow apoptosis execution [39].

Once initiated, MMP leads to the release into the cytosol of caspase-dependent proteins (i.e., cytochrome c or Smac/DIABLO) and caspase-independent proteins (such as apoptosis-inducing factor, AIF, or EndoG) with consequent coordinated cell degradation [40]. Concomitantly, MMP provokes a mitochondrial failure with dissipation of the inner membrane potential (
), subsequent arrest of OXPHOS and ATP synthesis, and increased ROS level. Therefore, MMP constitutes a point of no return of the activation cascade of cell death [41].

#### 3. Mitochondria in Liver Pathology

Most liver pathologies, including alcoholic liver disease, nonalcoholic fatty liver disease (NAFLD) and nonalcoholic steatohepatitis (NASH), drug-induced hepatotoxicity, viral hepatitis, and HCC, are characterized by mitochondrial dysfunctions. Moreover, during liver surgery, liver cells, in particular hepatocytes and endothelial cells suffer ischemia/reperfusion (
) injury. In the liver, as well as in other organs such as brain and heart,
injury involved mitochondrial permeability transition [1]. Since these abnormalities affect all the aforementioned physiological functions of mitochondria, we will review their roles in liver pathologies with a particular focus on the aspects of cell death regulation, alteration of hepatocyte metabolism, and disruption of ROS homeostasis.

##### 3.1. Mitochondria in Cell Death Regulation

Mitochondria are key organelles in the development of liver diseases characterized by hepatocyte death and subsequent inflammation (Figure 3). Actually, increased hepatocyte apoptosis has been correlated with inflammation, fibrosis, and cell turnover, conditions that are permissive for the development of HCC [2]. Hepatocyte mitochondria are essential in making effective the extrinsic pathway activated by many ligands, such as Fas, TRAIL or TNF-
[2]. Moreover, constitutive expression of both anti-apoptotic proteins
and Mcl-1, belonging to the Bcl-2 family, is required to avoid spontaneous caspase
activation, suggesting essential cytoprotective functions of these proteins in the hepatocyte [42, 43]. Bcl-2 is not constitutively expressed in the liver; however, it can be induced in order to cope with
, as shown in ischemic preconditioning during partial hepatectomy [44, 45].

Figure 3: The mitochondria are central organelles in determining cell fate in liver diseases. Hepatocyte cell death is common to many liver diseases. Different stress stimuli can induce death signaling, such as toxic free fatty acids, DNA damage, endoplasmic reticulum (ER) stress observed in metabolic disease. In these contexts, mitochondria are essential to determine cell fate, as in hepatocyte the activation of the intrinsic pathway of apoptosis by cell death receptors is not usually sufficient to induce cell death and liberation of proapoptotic factors from mitochondria is a mostly necessary event. Moreover, previous alterations of mitochondrial function causing decreased ATP synthesis can induce a shift from apoptotic to necrotic cell death.

Fas- and TRAIL-mediated apoptosis are involved in viral hepatitis, playing a crucial role in the elimination of infected cells and the hepatitis viral core protein binds Mcl-1 impairing its cytoprotective function [46–48]. TNF-
is secreted by infiltrating cytotoxic T lymphocytes during HBV infection and its apoptotic effect seems to be mediated by HBVx protein [2]. Mitochondrial apoptosis is also involved in the pathogenesis of NAFLD and in NASH [15]. In an experimental model using mice fed with a methionine and choline deficient diet, apoptosis was induced by an increase hepatic expression of functional p53, with a concomitant increase in the cleavage of Bid to tBid and a decrease expression of
[49]. Moreover, p53 was also responsible for TRAIL receptor expression, linking intrinsic and extrinsic apoptosis pathway in NASH [49]. Recently, saturated free fatty acids have been shown to activate the proapoptotic proteins Bim and Bax via JNK, thus inducing MMP, and also increase ROS production [50].

Hepatocyte necrosis is usually considered an accidental (nonprogrammed) form of cell death, resulting from metabolic failure and consequent rapid ATP depletion [51]. It has been firstly described during
injury following liver transplantation or hepatectomy, but it is also described in NASH. In fact, hepatocytes necrosis is associated with significant inflammatory response, due to the liberation of IL1-
, TNF-
and other newly described proinflammatory proteins, namely, damage-associated molecular-pattern (DAMP) molecules, such as HMGB1, that activate innate immunity response, such liver resident macrophages (Kupffer cells) and polymorphonuclear cells [45, 51–54]. Recently, accumulated evidence indicates that necrosis can also occur in a regulated manner and that the liberation of cytokines from dying cells can function as a sentinel signal alerting to the need for defensive response [51]. This regulated or programmed necrosis (necroptosis) is initiated by death receptors, like apoptosis, but requires activation of specific kinases (receptor interacting proteins 1 and 3) and its execution involves the active disintegration of mitochondrial, lysosomal, and plasma membranes [55]. Interestingly, in the context of
injury, the PTPC opening seems to be a common event anticipating both necrotic cell death and apoptosis, reinforcing the idea that programmed necrosis may be involved in clinical and pathological contexts. In an experimental model of orthotopic liver transplantation in rats, inhibition of PTP by cyclosporine A or acidic pH improved mitochondrial and hepatocellular functions, in particular decreasing the percentage of apoptotic cells but not of necrotic cells [56, 57]. These results seem to confirm the concept that apoptosis is typically an early event in hepatocyte injury. Importantly, in steatotic livers submitted to ischemia/reperfusion, necrosis is predominant compared with normal liver in which apoptosis is the main form of cell death [52, 53]. This difference has been partially linked to the metabolic/energetic difference between steatotic livers and normal liver [52] since fatty liver mitochondria have a decreased content of cytochromes c oxidase, produce superoxide anion and H2O2 at increased rate and have an increase content in UPC-2 compared with normal livers, resulting in decreased ATP production that affects apoptosis execution, and favors necrosis [58].

##### 3.2. Mitochondria in Alteration of Hepatocyte Metabolism

The aforementioned data suggest that mitochondria may be the convergence point between various metabolic stresses and cell death in hepatocyte. In this context, it merits noting that the cytosolic glucokinase, or hexokinase IV, the hepatic/pancreatic isoform of hexokinase, has been recently reported to be associated to mitochondrial proteins, such as Bad, at the MOM [59, 60]. The association of the pro-apoptotic protein Bad with the glucokinase suggests that a close integration exists between the pathways of glucose metabolism and apoptosis [59].

Many studies on obese, diabetic, or NASH patients have shown functional and structural abnormalities in hepatocyte mitochondria, such as OXPHOS impairment or megamitochondria [61]. Interestingly, both increased or decreased
-oxidation in insulin resistant hepatocytes has been reported as characteristic of liver steatosis and insulin resistance [16, 62, 63]. Decrease in
-oxidation activity induces diacylglycerol (DAG) accumulation and steatosis in the hepatocyte with concurrent activation of PKC pathway and inhibition of insulin signaling [62]. In insulin-resistant patients an increased activity of hepatic
-oxidation was observed and this was correlated to an increase in ROS production [61, 64]. Elevated
-oxidation could be an adaptive mechanism to limit free fatty acid lipotoxicity, thus providing large amounts of reduced equivalents (NADH) regardless of energetic requirements finally promoting ROS production due to impairment of respiratory chain [18]. These results linked mitochondrial metabolic dysfunctions to oxidative stress due to increased ROS production.

##### 3.3. Mitochondria in Disruption of ROS Homeostasis

Increased ROS production has been described in most liver pathologies. Augmented generation of mitochondrial ROS has been reported in various animal models of NASH, namely, genetically obese-diabetic ob/ob mice [58] and rats fed with a choline-deficient diet [65]. Moreover, mitochondria can be an ectopic site of cytochromes P450 2E1 expression [61, 66], where it can produce ROS and induce lipid peroxidation, as shown in the liver of an experimental model of diabetic rat [67].

Mitochondrial dysfunctions and ROS generation have been clearly shown in alcoholic liver disease [68]. Excessive ethanol consumption perturbs sinusoidal blood flow, inducing ischemia regions, and causes increased production of TNF-
, which induces inflammatory cell infiltration and an increase in hepatic O2 consumption [69, 70]. Chronic ethanol consumption induces profound disruption in mitochondrial metabolism, in particular decreasing the rate of ATP synthesis, thus placing hepatocytes under bioenergetic stress [68]. Under alcohol feeding, mitochondria contribute to the production of ROS in hepatocytes through various mechanisms. Ethanol metabolism increases the availability of NADH, resulting in a more reduced state of complexes I and III of the respiratory chain with a consequent increased probability of superoxide ion production [71]. Moreover, chronic alcohol consumption decreases mitochondrial protein synthesis mainly due to alcohol-mediated damage to mtDNA, contributing to decreased functioning of the oxidative phosphorylation system [72–74].

Mitochondrial ROS also play an important role in viral hepatitis. HCV core protein directly interacts with mitochondria and inhibits complex I activity, inducing an increased production of mitochondrial ROS, reducing threshold for Ca2+ and ROS-induced MMP [75]. Moreover, it has been recently shown that during HBV infection, HBx protein interacts with mitochondria, increasing ROS production [76]. The increase in ROS production was necessary, although insufficient, to induce the proinflammatory enzyme cyclooxygenase 2 (COX-2), linking mitochondrial dysfunction with liver inflammation in HBV infection [76]. Numerous investigations have shown that mitochondrial dysfunction is a major mechanism of drug- (or drug-metabolite-) induced liver injury [77]. Different mechanisms of mitochondrial dysfunction have been described in drug-induced hepatotoxicity, including membrane permeabilization, OXPHOS impairment, inhibition of fatty acid oxidation, and mtDNA depletion, and it appears that overproduction of reactive oxygen species by the damaged mitochondria could play a major role [77]. Finally, there is evidence showing a role of ROS in hepatocarcinogenesis [78]. Chemical hepatocarcinogens, such as the mycotoxin aflatoxin B1 and 2-acetylaminofluorene (2-AAF), induced increased ROS production in hepatocytes. In particular, 2-AAF altered mitochondrial redox cycling and it activated NADPH oxidase, an important ROS producing enzyme, through PI3K/Akt pathway [79–81]. Growth factors and activated oncogenes also induce ROS overproduction. Cultured cells treated with epidermal growth factor (EGF) and platelet-derived growth factor (PDGF) showed increased levels of H2O2 [82, 83]. Double transgenic mice bearing liver-targeted expression of transforming growth factor and the oncogene c-myc develop HCC as early as 4 and 8 months of age and elevated ROS levels associated with lipid peroxidation, mitochondrial damage and decreased GSH were already observed at 2-3 months of age [84].

Thus, it is clear that even a mild dysfunction of mitochondria in the liver could lead to hepatic and systemic pathological conditions and the identification of type and timing of mitochondrial lesions could allow major advancement in prevention, early diagnosis and treatment of systemic and liver diseases.

#### 4. Mitochondria in the Cytoprotection of Damaged Liver Cells to Ensure Homeostasis in Chronic Liver Diseases

Mitochondrial dysfunction is described in various hepatic diseases or lesions, such as NAFLD, I/R injury, drug toxicity or hepatocellular carcinoma, and it is often detected as an early alteration, suggesting its causative effect [6, 85–87]. Cells have developed different mechanisms to keep mitochondrial integrity or to prevent the effects of mitochondrial lesions, such as disposal of damaged mitochondria by autophagy/mitophagy, increased biogenesis of mitochondria or regulation of signaling pathways to ensure energy metabolism and limit cell death and inflammatory response.

##### 4.1. Increased Biogenesis of Mitochondria

Regulation of mitochondria biogenesis is one of the mechanisms developed by cells to keep mitochondrial integrity or to prevent the effects of mitochondrial lesions. The peroxisome proliferator-activated receptor gamma coactivator-1 alpha (PGC-1 alpha) belongs to the family of PGC-1 transcriptional coactivators (PGC-1 alpha, PGC-1 beta and PRC), which have been shown to be master regulators of mitochondrial biogenesis, and cellular energy metabolism in many organs, including liver [88, 89]. PGC-1 alpha is present at low but inducible levels in the liver where it also regulates most of the metabolic pathways, including gluconeogenesis, fatty acid
-oxidation, ketogenesis and heme biosynthesis (Figure 4) [90–93]. Under stress conditions, such as low temperature, fasting or energy deprivation, PGC-1 alpha is activated both transcriptionally by cAMP response element binding protein (CREB) and post-traductionally by AMP-activated-protein-kinase- (AMPK-) induced phosphorylation and SIRT1-mediated deacetylation [89]. Following PGC-1 alpha activation, different nuclear factors are subsequently activated. In particular, an activation of the nuclear respiratory factors 1 and 2 (NRF-1 and NRF-2) is observed and is followed by increased expression of multiple mitochondrial proteins. Moreover, PGC-1 alpha activates the nuclear receptors peroxisome proliferator-activated receptor alpha (PPAR alpha) and the estrogen-related receptor alpha (ERRalpha) both promoting the transcription of genes involved in
-oxidation, such as medium chain acyl-CoA dehydrogenase and carnitine palmitoyltransferase-1A (CPT-1A) [94, 95]. The absence of adequate levels of PGC-1 alpha is correlated with mice developing fasting hypoglycemia and hepatic steatosis, while mouse models of type 1 and type 2 diabetes showed high hepatic levels of PGC-1 alpha [90]. However, it has been recently shown that the different tissue-specific functions of PGC-1 alpha are tightly and independently regulated [96]. In particular, S6 kinase-1 (S6K1), activated in the liver upon feeding, can phosphorylate PGC-1 alpha, decreasing its capacity to turn on genes of gluconeogenesis, while keeping the functions of activator of mitochondrial and fatty acid oxidation genes intact [96]. S6K1, liver kinase B1 and AMPK are key kinases in the regulation of energy metabolism in the liver. Actually, AMPK is emerging as a kinase that links energy metabolism to mitochondrial function and biogenesis since components downstream of AMPK may contribute to stabilize mitochondrial membrane potential for hepatocyte survival, strengthening the relationship between fuel metabolism and cell survival [10]. Actually, in the liver, the activation of AMPK has been shown to decrease gluconeogenesis and fatty acid synthesis, to increase fatty acid oxidation and mitochondrial biogenesis and this could be linked to PGC-1 alpha phosphorylation, as previously observed in skeletal muscle [97, 98]. Interestingly, the hepatitis B virus (HBV) uses the transcriptional machinery involved in the hepatic response to fasting for its own amplification, thus HBV life cycle is under the control of PGC-1 alpha that could be a new target for antiviral therapy [99]. The dynamic changes in mitochondrial morphology, connectivity, and subcellular distribution are also major mechanisms in cellular homeostasis. They are critically dependent on a highly regulated fusion and fission machinery. Mitochondrial function, dynamics, and quality control are vital for the maintenance of tissue integrity [100]. In the liver, it has been shown that specific protection against hepatocyte mitochondrial dysfunction plays a preventive role in early stages of fibrogenesis, delaying, but not avoiding, its onset [101]. In this context, it is interesting to note that TGF-β/Smad3 signaling pathway, known to be implicated in liver fibrogenesis, has been shown to regulate glucose and energy homeostasis. Smad3-deficient mice are protected from diet-induced obesity and diabetes and Smad3 acts as a repressor of PGC-1α expression, thus suggesting a link between failure in mitochondrial biogenesis, metabolic syndrome, and liver fibrosis [102].

Figure 4: Mitochondria biogenesis allows tissue adaption under stress. Mitochondria biogenesis has been recently recognized as a central pathway in the adaptation of stress conditions in the liver, such as fasting, energy deprivation, hypoxia, or alcohol consumption. Different signaling pathways converge on the master regulator of mitochondria biogenesis, PGC1-alpha. In particular, AMPK and PKA signaling may activate gene transcription controlled by PGC1-alpha, while the TGF-β has been shown to inhibit PGC1-alpha-induced gene transcription.

##### 4.2. Autophagy and Mitophagy as Mechanisms to Limit Mitochondrial Lesions

Autophagy is a cellular pathway by which cytoplasmic materials, including organelles, reach lysosomes for degradation. Autophagy may occur either as a general phenomenon, for instance, during nutrient deprivation, or it can specifically target distinct cellular structures, such as damaged mitochondria (mitophagy) [13]. An important interplay exists between induction of autophagy and mitochondria. Actually mitochondria seem to have a key role in general autophagy as they may supply membranes for the biogenesis of autophagosomes during starvation [103]. Moreover, low ATP production or enhanced ROS generation by mitochondria induces general autophagy [104, 105]. The selective removal of mitochondria by mitophagy regulates mitochondrial number to match metabolic demand and is considered a form of quality control to remove damaged mitochondria [106]. Induction of general autophagy by a sublethal stress before a lethal stress can protect cells against cell death [13]. Indeed, we showed that ischemic preconditioning of livers previously treated by chemotherapy or steatotic livers induced autophagy and decreased necrosis without altering apoptosis. [45, 54]. The elimination of damaged mitochondria has been correlated to resistance of residual mitochondria to MMP and opening of PTP, two early events of apoptotic/necrotic cell death. This can be explained either by the removal of mitochondria that have a low threshold for permeabilization or by the fact that MMP or PTP opening occurs in a fraction of mitochondria and may activate autophagic disposal of depolarized mitochondria [106, 107]. Different mechanisms may regulate mitophagy. The dual system PINK1-Parkin is well described especially in neural tissues. The stabilization of the kinase PINK1 occurs at the surface of mitochondria with low
with the subsequent recruitment of the ubiquitin ligase Parkin and ubiquitinylation of outer membrane proteins [108]. Mitophagy can be also stimulated by histone deacetylase 6, which is recruited to mitochondria and catalyzes proautophagic cytoplasmic deacetylation reactions [109].

Interestingly, although hepatic PINK1-expression is described [110], to our knowledge, no reports on PINK1 dependent mitophagy in the liver are published. Another mechanism of mitophagy involves the activation of AMPK [111]. AMPK phosphorylates and activates ULK1, one of the initiators of autophagy and the genetic loss of AMPK or ULK1 results in defective mitophagy in mammalian liver and C. elegans. These findings showed a conserved mechanism coupling nutrient status with autophagy and cell survival [111]. Interestingly, mitochondrial degradation by autophagy was also described in the liver of GFP-LC3 transgenic mice following nutrient deprivation, reinforcing the results linking AMPK regulation of mitophagy [112].

##### 4.3. Mitochondria Can Integrate Energy, Nutrient Metabolism, and Oxidative Stress Responses Determining Cell Fate

Insulin, secreted by pancreatic beta cells upon nutrient stimulation, is one of the most important regulators of nutrient utilization and metabolic homeostasis in the liver. Insulin resistance, a hallmark of NASH and more generally of metabolic syndrome and type II diabetes, is accompanied by reduction of mitochondrial OXPHOS activity and increased ROS production [113]. On the other hand, ROS produced during mitochondrial OXPHOS promote insulin signaling through oxidation of insulin receptor and inhibition of phosphatases, such as PTP1B and PTEN [113]. Importantly, recent investigations pointed out a tight molecular crosstalk between cell survival or cell death pathways and energy metabolism. Using ex vivo multinuclear NMR-spectroscopy to study metabolic pathways of [U-(13)C] glucose in mouse liver during Fas-induced apoptosis, Gottschalk et al. found early upregulations in glucose metabolic pathways occurred prior to any visible signs of apoptosis, accompanied by an increased mitochondrial energy production and cellular glutathione synthesis [114]. This metabolic shift seems to potentially contribute to the initiation of apoptosis by mitochondrial energy production and cellular glutathione stores, thus orienting cell fate towards a less pro-inflammatory death. A biochemical analysis using liver mitochondria of two strains of mice (A/J and C57Bl/6, respectively, resistant and susceptible to high-fat diet-induced hepatosteatosis) confirmed a rapid increase by high-fat diet feeding of the respiration rate in A/J but not C57Bl/6 mice. Importantly, ATP production was the same in both types of mitochondria, indicating increased uncoupling of the A/J mitochondria [115]. These results suggest that livers can adapt to high-fat diet feeding by increasing the activity of the oxidative phosphorylation chain and its uncoupling to dissipate the excess of incoming metabolic energy and to reduce the production of ROS [115].

As we mentioned above, liver mitochondria are essential in ammonia detoxification following protein catabolism. In recent years, studies from several laboratories have uncovered a number of factors and pathways that appear to be critically involved in the pathogenesis of hepatic encephalopathy. Foremost is oxidative and nitrosative stress (ONS) and the MMP playing major roles in the mechanism of ammonia-induced astrocyte swelling [116]. The accumulation of intramitochondrial glutamine has been involved. Norenberg et al. [117] were first to describe that the newly synthesized glutamine could be toxic when subsequently metabolized in mitochondria by phosphate-activated glutaminase, yielding glutamate and ammonia. Thus, glutamine can be considered as a carrier of ammonia. The authors propose to consider the intramitochondrial glutamine as a Trojan horse that interferes with mitochondrial function giving rise to excessive production of free radicals and induction of the MPT, two phenomena known to bring about astrocyte dysfunction, including cell swelling.

Moreover, an ammonia-induced increase in intracellular Ca2+ has been described which activates a number of enzymes promoting the synthesis of reactive oxygen-nitrogen species, including constitutive nitric oxide synthase, NADPH oxidase and phospholipase A2. ONS subsequently induces the opening of PTP and activates mitogen-activated protein (MAP) kinases and the transcription factor nuclear factor-kappaB (NF-
B). These factors act to generate additional reactive oxygen-nitrogen species, to phosphorylate various proteins and transcription factors, and to cause mitochondrial dysfunction [26]. The pathways and factors described above provide attractive targets for identifying agents potentially useful in the therapy of HE and other hyperammonemic disorders. The most promising of them is the glutamate/glutamine cycle. Indeed, in hyperoxia, glutamine has been described to protect cellular structures, especially mitochondria, from damage. This has been attributed to the activity of the tricarboxylic acid cycle enzyme alpha-ketoglutarate dehydrogenase that was partially protected by its indirect substrate, glutamine, indicating a mechanism of mitochondrial protection [118]. Glutamate dehydrogenase (GDH), a mitochondrial enzyme linking the Krebs cycle to the multifunctional amino acid glutamate could be also an interesting target. Indeed, GDH controls production and consumption of glutamate. GDH activity is under the control of several regulators, conferring to this enzyme energy-sensor property. Indeed, GDH directly depends on the provision of the cofactor NADH/NAD(+), rendering the enzyme sensitive to the redox status of the cell. Moreover, GDH is allosterically regulated by GTP and ADP. GDH is also regulated by ADP-ribosylation, mediated by a member of the energy-sensor family sirtuins, namely, SIRT4. In the brain, GDH ensures the cycling of the neurotransmitter glutamate between neurons and astrocytes. GDH also controls ammonia metabolism and detoxification, mainly in the liver and kidney. Eng and Abraham [119] have described that ammonia, generated from Gln deamination (glutaminolysis) in mitochondria, functions as an autocrine- and/or paracrine-acting stimulator of autophagic flux. Recently, Nissim et al. [120] reported a downregulation of hepatic urea synthesis by oxypurines. Indeed, xanthine and uric acid, both physiologically occurring oxypurines, inhibited the hepatic synthesis of N-acetylglutamate, the key regulator of the first step of mitochondrial urea cycle.

As discussed above, mitochondria are a main source of ROS in hepatocytes and ROS importantly contribute in liver health and disease. While ROS has been commonly associated to lipid, protein, and DNA oxidation and consequent cellular damage, recent studies have shown that mitochondria-generated ROS may be regulated and may regulate many signaling pathways [27, 121]. Oxidative stress may activate prosurvival pathways in hepatocytes, such as NF-
B and NRFs [122–124]. NF-
B regulates a complex network of pathways, as it is known to control the transcription of over 150 genes [122]. Depending on cell type, microenvironmental conditions and eventually costimulated pathways, NF-
B may exert either a pro-survival or a proapoptotic function [122, 125]. In the context of hepatic oxidative stress, it has been shown that NF-
B may induce antiapoptotic factors, such as XIAP, and function like antioxidants in preventing TGF-beta 1-JNK induced-apoptosis [126]. Moreover, NF-
B collaborates with p38 MAP kinase signaling cascade to protect hepatocytes from liver injury induced by TNF-alpha [125]. NRFs also regulates oxidative stress response in the liver. In particular, NRF-1 has been shown to promote cell survival of hepatocytes during development, sustaining the transcription of antioxidant genes and protecting embryonic hepatocytes from TNF-mediated apoptosis [124]. Moreover, NRF-1 has been shown to be induced under prooxidant conditions and to promote the transcription of mitochondrial transcription factor A (Tfam), required for mitochondrial DNA transcription and replication [123]. Hypoxia is another clear example of cell signaling mediated by ROS. Hypoxia is a clinical relevant event both in liver ischemia/reperfusion injury and in hepatocellular carcinoma development. It leads to an increase in production of H2O2 from mitochondrial complex III, thus creating a cytosolic signal that stabilizes the hypoxia inducible transcription factors HIF-1 [27, 127]. Moreover, during hypoxia ROS activates AMPK, which in turn phosphorylates Na/K ATPase (in order to promote its endocytosis) and mTOR (in order to decrease protein translation), thus contributing to energy conservation [128, 129]. In addition, hypoxia-induced mitochondrial ROS enhance the DNA binding of NF-
B through a redox-dependent mechanism involving the mitochondrial glutathione (mGSH) pool in cancer cells, including hepatoma cell lines [130, 131]. In this context, mGSH regulates the intensity of ROS diffusion in the cytoplasm, allowing activation of the c-Src kinase, with subsequent phosphorylation of the inhibitory subunit I
B, activation of NF-
B and promotion of cancer cell survival [127, 130]. The liver is one of the organs with the highest content of GSH and mGSH plays a central role in regulating both in antioxidant defense against excessive ROS production and in regulation of ROS signaling in liver physiology and pathology [130]. Alcohol consumption has been shown to sensitize hepatocytes to TNF because of mGSH depletion through impaired transport of GSH to mitochondria [132]. Interestingly, GSH transport impairment and TNF sensitization correlate with free cholesterol accumulation in mitochondrial membranes and seem to be a common pro-inflammatory mechanism in both alcoholic and nonalcoholic steatohepatitis [133]. Similar alterations in mGSH regulation have been reported in liver cirrhosis, in particular in an experimental model of secondary biliary cirrhosis in rats induced by bile-duct ligation [134, 135].

During the past decade, a new family of enzymes, the nicotinamide-adenine-dinucleotide- (NAD-) dependent protein deacetylases named sirtuins, has been described to contribute to extended lifespan many animal models, including mammals [136]. Interestingly of the six mammalian sirtuins, three (SIRT3, 4, and 5) are expressed in the mitochondria where they mediate physiologic adaptation to reduced energy consumption [137]. In the liver, SIRT4 activity was shown to decline during calorie restriction, allowing the consumption of glutamine as a fuel source for glucose synthesis. Moreover, SIRT4 depletion increased fatty acid oxidation [138]. Mitochondrial sirtuins could be also interesting targets in the regulation of ammonia production and disposal. Nakagawa et al. [139] have shown that the sirtuin SIRT5 activates CPS1, which we mentioned before as the first enzyme in the urea cycle. In mice, NAD in liver mitochondria increases during fasting, thereby triggering SIRT5-mediated deacetylation of CPS1 and adaptation to increase in amino acid catabolism. These data indicate SIRT5 also has an emerging role in the metabolic adaptation to fasting, high protein diet and calorie restriction. Finally, recent findings correlate SIRT3 to the production of ROS. In particular, SIRT3−/− cells produce increased levels of ROS and have concomitantly a reduced ATP production [11, 12, 140]. These results suggest that SIRT3-mediated deacetylation of electron transport chain may render OXPHOS more efficient [137]. Moreover, SIRT3 may deacetylate and activate the antioxidant enzyme mitochondrial superoxide dismutase (SOD2) and the isocitrate dehydrogenase 2, which generates NADPH for the glutathione synthesis, in mice [141–143]. The sirtuins’ antiaging role and their ability of controlling energy metabolism make them interesting target in cancer and metabolic diseases. Interestingly, in a mouse model of metabolic syndrome-associated liver cancer, overexpression of SIRT1 reduced the susceptibility to liver cancer and improved hepatic protection from both DNA damage and metabolic damage [136]. However, recent studies showed that SIRT1 was upregulated in HCC and it has a role in telomere maintenance [144, 145]. Downregulation of SIRT1 suppressed proliferation of HCC cells and induced cellular senescence or apoptosis [144]. Finally, many recent papers show a possible synergic action of cytosolic and mitochondrial sirtuins in regulating glucose and lipid metabolism in the liver [138, 140, 146–148]. SIRT1 has been shown to regulate hepatic glucose and lipid metabolism by activating AMPK and by inducing gluconeogenic genes via activation of PGC-1 alpha in hepatic cell and mouse liver [146, 147]. Interestingly, SIRT1 did not regulate the PGC-1 alpha effects on mitochondrial biogenesis. The mitochondrial SIRT3 was shown to positively modulate fatty acid oxidation and ATP production, in particular deacetylating the long-chain acyl-CoA dehydrogenase and Complex I of the electron transport chain [140, 148]. Finally, in a recent paper, high-fat diet induced a decrease of hepatic SIRT3, hyperacetylation of mitochondrial proteins and fatty liver in mice [149].

Altogether, the studies reviewed show that mitochondria are much more dynamic organelles than considered traditionally. They are key organelles in the integration and adaptation to external stimuli, such as changing composition of diet (i.e., calorie restriction versus high fat diet), hypoxia, cold exposure, or physical exercise [150]. Mitochondrial homeostasis is a highly controlled process balancing organelle biogenesis and degradation (essentially by autophagy/mitophagy) and an alteration of this balance may bring to organelle dysfunction, contributing to the development of liver chronic diseases.

#### 5. Conclusions

The liver is one of the organs richest in mitochondria. Hepatic mitochondria have unique features compared to other organs’ mitochondria, since they are the hub that integrates hepatic metabolism of carbohydrates, lipids, and proteins. Thus, correct functioning of hepatic mitochondria is essential not only to prevent liver disease, such as NAFLD, but also to avoid systemic diseases, such as ammonia-induced hepatic encephalopathy. Mitochondria are also essential in hepatocyte survival as mediator of apoptosis and necrosis. Hepatocyte cell death is involved in most liver pathologies, such as alcoholic and nonalcoholic steatohepatitis, viral hepatitis, liver fibrosis, and carcinogenesis. Hepatocytes have developed different mechanisms to keep mitochondrial integrity or to prevent the effects of mitochondrial lesions, in particular regulating organelle biogenesis and degradation. A better knowledge of the mechanisms and pathways involved in mitochondria homeostasis should improve preventive and therapeutic strategies for liver diseases.

#### Abbreviations

2-AAF: | 2-Acetylaminofluorene
DAG: | Diacylglycerol
GS: | Glutamine synthetase
GSH: | Glutathione
HCC: | Hepatocellular carcinoma
MIM: | Mitochondrial inner membrane
MMP: | Mitochondrial membrane permeabilization
MOM: | Mitochondrial outer membrane
MRC: | Mitochondrial respiratory chain
NAG: | N-acetyl-L-glutamate
NASH: | Nonalcoholic steatohepatitis
OXPHOS: | Oxidative phosphorylation
PTP: | Permeability transition pore
ROS: | Reactive oxygen species.

#### References

1. G. Kroemer, L. Galluzzi, and C. Brenner, “Mitochondrial membrane permeabilization in cell death,” Physiological Reviews, vol. 87, no. 1, pp. 99–163, 2007. View at Publisher · View at Google Scholar · View at Scopus
2. H. Malhi, M. E. Guicciardi, and G. J. Gores, “Hepatocyte death: a clear and present danger,” Physiological Reviews, vol. 90, no. 3, pp. 1165–1194, 2010. View at Publisher · View at Google Scholar · View at Scopus
3. K. L. Veltri, M. Espiritu, and G. Singh, “Distinct genomic copy number in mitochondria of different mammalian organs,” Journal of Cellular Physiology, vol. 143, no. 1, pp. 160–164, 1990. View at Scopus
4. P. H. Yin, H. C. Lee, G. Y. Chau et al., “Alteration of the copy number and deletion of mitochondrial DNA in human hepatocellular carcinoma,” British Journal of Cancer, vol. 90, no. 12, pp. 2390–2396, 2004. View at Scopus
5. A. Chatterjee, S. Dasgupta, and D. Sidransky, “Mitochondrial subversion in cancer,” Cancer Prevention Research, vol. 4, no. 5, pp. 638–654, 2011. View at Publisher · View at Google Scholar · View at Scopus
6. R. S. Rector, J. P. Thyfault, G. M. Uptergrove et al., “Mitochondrial dysfunction precedes insulin resistance and hepatic steatosis and contributes to the natural history of non-alcoholic fatty liver disease in an obese rodent model,” Journal of Hepatology, vol. 52, no. 5, pp. 727–736, 2010. View at Publisher · View at Google Scholar · View at Scopus
7. M. E. Breuer, P. H. G. M. Willems, F. G. M. Russel, W. J. H. Koopman, and J. A. M. Smeitink, “Modeling mitochondrial dysfunctions in the brain: from mice to men,” Journal of Inherited Metabolic Disease, vol. 35, no. 2, pp. 193–210, 2011. View at Publisher · View at Google Scholar · View at Scopus
8. S. Ong and A. B. Gustafsson, “New roles for mitochondria in cell death in the reperfused myocardium,” Cardiovascular Research, vol. 94, no. 2, pp. 190–196, 2012.
9. D. Degli Esposti, M. C. Domart, M. Sebagh et al., “Autophagy is induced by ischemic preconditioning in human livers formerly treated by chemotherapy to limit necrosis,” Autophagy, vol. 6, no. 1, pp. 172–174, 2010. View at Publisher · View at Google Scholar · View at Scopus
10. Y. M. Yang, C. Y. Han, Y. J. Kim, and S. G. Kim, “AMPK-associated signaling to bridge the gap between fuel metabolism and hepatocyte viability,” World Journal of Gastroenterology, vol. 16, no. 30, pp. 3731–3742, 2010. View at Publisher · View at Google Scholar · View at Scopus
11. H. S. Kim, K. Patel, K. Muldoon-Jacobs et al., “SIRT3 is a mitochondria-localized tumor suppressor required for maintenance of mitochondrial integrity and metabolism during stress,” Cancer Cell, vol. 17, no. 1, pp. 41–52, 2010. View at Publisher · View at Google Scholar · View at Scopus
12. K. H. Kim, Y. S. Kum, Y. Y. Park et al., “The protective effect of bee venom against ethanol-induced hepatic injury via regulation of the mitochondria-related apoptotic pathway,” Basic and Clinical Pharmacology and Toxicology, vol. 107, no. 1, pp. 619–624, 2010. View at Publisher · View at Google Scholar · View at Scopus
13. D. R. Green, L. Galluzzi, and G. Kroemer, “Mitochondria and the autophagy-inflammation-cell death axis in organismal aging,” Science, vol. 333, no. 6046, pp. 1109–1112, 2011. View at Publisher · View at Google Scholar
14. M. Pérez-Carreras, P. Del Hoyo, M. A. Martín et al., “Defective hepatic mitochondrial respiratory chain in patients with nonalcoholic steatohepatitis,” Hepatology, vol. 38, no. 4, pp. 999–1007, 2003. View at Publisher · View at Google Scholar · View at Scopus
15. E. Bugianesi, A. J. McCullough, and G. Marchesini, “Insulin resistance: a metabolic pathway to chronic liver disease,” Hepatology, vol. 42, no. 5, pp. 987–1000, 2005. View at Publisher · View at Google Scholar · View at Scopus
16. E. Fabbrini, S. Sullivan, and S. Klein, “Obesity and nonalcoholic fatty liver disease: biochemical, metabolic, and clinical implications,” Hepatology, vol. 51, no. 2, pp. 679–689, 2010. View at Publisher · View at Google Scholar · View at Scopus
17. L. Boon, W. J. C. Geerts, A. Jonker, W. H. Lamers, and C. J. F. Van Noorden, “High protein diet induces pericentral glutamate dehydrogenase and ornithine aminotransferase to provide sufficient glutamate for pericentral detoxification of ammonia in rat liver lobules,” Histochemistry and Cell Biology, vol. 111, no. 6, pp. 445–452, 1999. View at Publisher · View at Google Scholar · View at Scopus
18. G. Vial, H. Dubouchaud, and X. M. Leverve, “Liver mitochondria and insulin resistance,” Acta Biochimica Polonica, vol. 57, no. 4, pp. 389–392, 2010. View at Scopus
19. G. Serviddio, F. Bellanti, R. Tamborra et al., “Uncoupling protein-2 (UCP2) induces mitochondrial proton leak and increases susceptibility of non-alcoholic steatohepatitis (NASH) liver to ischaemia-reperfusion injury,” Gut, vol. 57, no. 7, pp. 957–965, 2008. View at Publisher · View at Google Scholar · View at Scopus
20. R. S. Kaplan and J. A. Mayor, “Structure, function and regulation of the tricarboxylate transport protein from rat liver mitochondria,” Journal of Bioenergetics and Biomembranes, vol. 25, no. 5, pp. 503–514, 1993. View at Publisher · View at Google Scholar · View at Scopus
21. L. Caldovic and M. Tuchman, “N-acetylglutamate and its changing role through evolution,” Biochemical Journal, vol. 372, no. 2, pp. 279–290, 2003. View at Publisher · View at Google Scholar · View at Scopus
22. J. M. Matés, J. A. Segura, J. A. Campos-Sandoval et al., “Glutamine homeostasis and mitochondrial dynamics,” International Journal of Biochemistry and Cell Biology, vol. 41, no. 10, pp. 2051–2061, 2009. View at Publisher · View at Google Scholar · View at Scopus
23. S. W. M. Olde Damink, R. Jalan, and C. H. C. Dejong, “Interorgan ammonia trafficking in liver disease,” Metabolic Brain Disease, vol. 24, no. 1, pp. 169–181, 2009. View at Publisher · View at Google Scholar · View at Scopus
24. J. Albrecht, “Roles of neuroactive amino acids in ammonia neurotoxicity,” Journal of Neuroscience Research, vol. 51, no. 2, pp. 133–138, 1998. View at Publisher · View at Google Scholar
25. V. Felipo, C. Hermenegildo, C. Montoliu, M. Llansola, and M. D. Minana, “Neurotoxicity of ammonia and glutamate: molecular mechanisms and prevention,” NeuroToxicology, vol. 19, no. 4-5, pp. 675–682, 1998. View at Scopus
26. R. F. Butterworth, “Pathophysiology of hepatic encephalopathy: the concept of synergism,” Hepatology Research, vol. 38, no. 1, pp. S116–S121, 2008. View at Publisher · View at Google Scholar · View at Scopus
27. R. B. Hamanaka and N. S. Chandel, “Mitochondrial reactive oxygen species regulate cellular signaling and dictate biological outcomes,” Trends in Biochemical Sciences, vol. 35, no. 9, pp. 505–513, 2010. View at Publisher · View at Google Scholar · View at Scopus
28. T. A. Young, C. C. Cunningham, and S. M. Bailey, “Reactive oxygen species production by the mitochondrial respiratory chain in isolated rat hepatocytes and liver mitochondria: studies using myxothiazol,” Archives of Biochemistry and Biophysics, vol. 405, no. 1, pp. 65–72, 2002. View at Publisher · View at Google Scholar · View at Scopus
29. Y. Kushnareva, A. N. Murphy, and A. Andreyev, “Complex I-mediated reactive oxygen species generation: modulation by cytochrome c and NAD(P)+ oxidation-reduction state,” Biochemical Journal, vol. 368, no. 2, pp. 545–553, 2002. View at Publisher · View at Google Scholar · View at Scopus
30. H. Nohl, L. Gille, and K. Staniek, “Intracellular generation of reactive oxygen species by mitochondria,” Biochemical Pharmacology, vol. 69, no. 5, pp. 719–723, 2005. View at Publisher · View at Google Scholar · View at Scopus
31. D. C. Wallace, W. Fan, and V. Procaccio, “Mitochondrial energetics and therapeutics,” Annual Review of Pathology, vol. 5, pp. 297–348, 2010. View at Publisher · View at Google Scholar · View at Scopus
32. S. Rexroth, A. Poetsch, M. Rögner et al., “Reactive oxygen species target specific tryptophan site in the mitochondrial ATP synthase,” Biochimica et Biophysica Acta, vol. 1817, no. 2, pp. 381–387, 2012. View at Publisher · View at Google Scholar
33. M. O. Dietrich and T. L. Horvath, “The role of mitochondrial uncoupling proteins in lifespan,” Pflugers Archiv European Journal of Physiology, vol. 459, no. 2, pp. 269–275, 2010. View at Publisher · View at Google Scholar · View at Scopus
34. A. Letai, M. C. Bassik, L. D. Walensky, M. D. Sorcinelli, S. Weiler, and S. J. Korsmeyer, “Distinct BH3 domains either sensitize or activate mitochondrial apoptosis, serving as prototype cancer therapeutics,” Cancer Cell, vol. 2, no. 3, pp. 183–192, 2002. View at Publisher · View at Google Scholar · View at Scopus
35. S. Shimizu, M. Narita, and Y. Tsujimoto, “Bcl-2 family proteins regulate the release of apoptogenic cytochrome c by the mitochondrial channel VDAC,” Nature, vol. 399, no. 6735, pp. 483–487, 1999. View at Publisher · View at Google Scholar · View at Scopus
36. M. Zoratti and I. Szabo, “The mitochondrial permeability transition,” Biochimica et Biophysica Acta, vol. 1241, no. 2, pp. 139–176, 1995. View at Publisher · View at Google Scholar · View at Scopus
37. J. Montero, M. Mari, A. Colell et al., “Cholesterol and peroxidized cardiolipin in mitochondrial membrane properties, permeabilization and cell death,” Biochimica et Biophysica Acta, vol. 1797, no. 6-7, pp. 1217–1224, 2010. View at Publisher · View at Google Scholar · View at Scopus
38. C. Brenner and S. Grimm, “The permeability transition pore complex in cancer cell death,” Oncogene, vol. 25, no. 34, pp. 4744–4756, 2006. View at Publisher · View at Google Scholar · View at Scopus
39. A. Rasola and P. Bernardi, “Mitochondrial permeability transition in Ca2+-dependent apoptosis and necrosis,” Cell Calcium, vol. 50, no. 3, pp. 222–233, 2011. View at Publisher · View at Google Scholar · View at Scopus
40. J. E. Chipuk and D. R. Green, “Do inducers of apoptosis trigger caspase-indipendent cell death?” Nature Reviews Molecular Cell Biology, vol. 6, no. 3, pp. 268–275, 2005.
41. D. R. Green and G. Kroemer, “The pathophysiology of mitochondrial cell death,” Science, vol. 305, no. 5684, pp. 626–629, 2004. View at Publisher · View at Google Scholar · View at Scopus
42. T. Takehara, T. Tatsumi, T. Suzuki et al., “Hepatocyte-specific disruption of Bcl-xL leads to continuous hepatocyte apoptosis and liver fibrotic responses,” Gastroenterology, vol. 127, no. 4, pp. 1189–1197, 2004. View at Publisher · View at Google Scholar · View at Scopus
43. B. Vick, A. Weber, T. Urbanik et al., “Knockout of myeloid cell leukemia-1 induces liver damage and increases apoptosis susceptibility of murine hepatocytes,” Hepatology, vol. 49, no. 2, pp. 627–636, 2009. View at Publisher · View at Google Scholar · View at Scopus
44. F. Charlotte, A. L'Hermine, N. Martin et al., “Immunohistochemical detection of bcl-2 protein in normal and pathological human liver,” American Journal of Pathology, vol. 144, no. 3, pp. 460–465, 1994. View at Scopus
45. M. C. Domart, D. Degli Esposti, M. Sebagh et al., “Concurrent induction of necrosis, apoptosis, and autophagy in ischemic preconditioned human livers formerly treated by chemotherapy,” Journal of Hepatology, vol. 51, no. 5, pp. 881–889, 2009. View at Publisher · View at Google Scholar · View at Scopus
46. P. R. Galle, W. J. Hofmann, H. Walczak et al., “Involvement of the CD95 (APO-1/Fas) receptor and ligand in liver damage,” Journal of Experimental Medicine, vol. 182, no. 5, pp. 1223–1230, 1995. View at Publisher · View at Google Scholar · View at Scopus
47. B. Mundt, F. Kühnel, L. Zender et al., “Involvement of TRAIL and its receptors in viral hepatitis,” The FASEB Journal, vol. 17, no. 1, pp. 94–96, 2003. View at Scopus
48. N. K. Mohd-Ismail, L. Deng, S. K. Sukumaran, V. C. Yu, H. Hotta, and Y. J. Tan, “The hepatitis C virus core protein contains a BH3 domain that regulates apoptosis through specific interaction with human Mcl-1,” Journal of Virology, vol. 83, no. 19, pp. 9993–10006, 2009. View at Publisher · View at Google Scholar · View at Scopus
49. G. C. Farrell, C. Z. Larter, J. Y. Hou et al., “Apoptosis in experimental NASH is associated with p53 activation and TRAIL receptor expression,” Journal of Gastroenterology and Hepatology, vol. 24, no. 3, pp. 443–452, 2009. View at Publisher · View at Google Scholar · View at Scopus
50. N. Alkhouri, C. Carter-Kent, and A. E. Feldstein, “Apoptosis in nonalcoholic fatty liver disease: diagnostic and therapeutic implications,” Expert Review of Gastroenterology and Hepatology, vol. 5, no. 2, pp. 201–212, 2011. View at Publisher · View at Google Scholar · View at Scopus
51. R. S. Hotchkiss, A. Strasser, J. E. McDunn, and P. E. Swanson, “Mechanisms of disease: cell death,” New England Journal of Medicine, vol. 361, no. 16, pp. 1570–1583, 2009. View at Publisher · View at Google Scholar · View at Scopus
52. M. Selzner, H. A. RüDiger, D. Sindram, J. Madden, and P. A. Clavien, “Mechanisms of ischemic injury are different in the steatotic and normal rat liver,” Hepatology, vol. 32, no. 6, pp. 1280–1288, 2000. View at Scopus
53. C. Peralta, R. Bartrons, A. Serafin et al., “Adenosine monophosphate-activated protein kinase mediates the protective effects of ischemic preconditioning on hepatic ischemia-reperfusion injury in the rat,” Hepatology, vol. 34, no. 6, pp. 1164–1173, 2001. View at Publisher · View at Google Scholar · View at Scopus
54. D. Degli Esposti, M. Sebagh, P. Pham et al., “Ischemic preconditioning induces autophagy and limits necrosis in human recipients of fatty liver grafts, decreasing the incidence of rejection episodes,” Cell Death and Disease, vol. 2, no. 1, article e111, 2011. View at Publisher · View at Google Scholar · View at Scopus
55. P. Vandenabeele, L. Galluzzi, T. Vanden Berghe, and G. Kroemer, “Molecular mechanisms of necroptosis: an ordered cellular explosion,” Nature Reviews Molecular Cell Biology, vol. 11, no. 10, pp. 700–714, 2010. View at Publisher · View at Google Scholar · View at Scopus
56. C. Plin, P. S. Haddad, J. P. Tillement, A. Elimadi, and D. Morin, “Protection by cyclosporin A of mitochondrial and cellular functions during a cold preservation-warm reperfusion of rat liver,” European Journal of Pharmacology, vol. 495, no. 2-3, pp. 111–118, 2004. View at Publisher · View at Google Scholar · View at Scopus
57. J. S. Kim, L. He, T. Qian, and J. J. Lemasters, “Role of the mitochondrial permeability transition in apoptotic and necrotic death after ischemia/reperfusion injury to hepatocytes,” Current Molecular Medicine, vol. 3, no. 6, pp. 527–535, 2003. View at Publisher · View at Google Scholar · View at Scopus
58. S. Yang, H. Zhu, Y. Li et al., “Mitochondrial adaptations to obesity-related oxidant stress,” Archives of Biochemistry and Biophysics, vol. 378, no. 2, pp. 259–268, 2000. View at Publisher · View at Google Scholar · View at Scopus
59. N. N. Danial, C. F. Gramm, L. Scorrano et al., “BAD and glucokinase reside in a mitochondrial complex that integrates glycolysis and apoptosis,” Nature, vol. 424, no. 6951, pp. 952–956, 2003. View at Publisher · View at Google Scholar · View at Scopus
60. C. Arden, S. Baltrusch, and L. Agius, “Glucokinase regulatory protein is associated with mitochondria in hepatocytes,” FEBS Letters, vol. 580, no. 8, pp. 2065–2070, 2006. View at Publisher · View at Google Scholar · View at Scopus
61. K. Begriche, A. Igoudjil, D. Pessayre, and B. Fromenty, “Mitochondrial dysfunction in NASH: causes, consequences and possible means to prevent it,” Mitochondrion, vol. 6, no. 1, pp. 1–38, 2006. View at Publisher · View at Google Scholar · View at Scopus
62. D. Zhang, Z. X. Liu, S. C. Cheol et al., “Mitochondrial dysfunction due to long-chain Acyl-CoA dehydrogenase deficiency causes hepatic steatosis and hepatic insulin resistance,” Proceedings of the National Academy of Sciences of the United States of America, vol. 104, no. 43, pp. 17075–17080, 2007. View at Publisher · View at Google Scholar · View at Scopus
63. D. Pessayre, “Role of mitochondria in non-alcoholic fatty liver disease,” Journal of Gastroenterology and Hepatology, vol. 22, no. 1, pp. S20–S27, 2007. View at Publisher · View at Google Scholar · View at Scopus
64. D. Pessayre and B. Fromenty, “NASH: a mitochondrial disease,” Journal of Hepatology, vol. 42, no. 6, pp. 928–940, 2005. View at Publisher · View at Google Scholar · View at Scopus
65. K. Hensley, Y. Kotake, H. Sang et al., “Dietary choline restriction causes complex I dysfunction and increased H2O2 generation in liver mitochondria,” Carcinogenesis, vol. 21, no. 5, pp. 983–989, 2000. View at Scopus
66. M. A. Robin, H. K. Anandatheerthavarada, J. K. Fang, M. Cudic, L. Otros, and N. G. Avadhani, “Mitochondrial targeted cytochrome P450 2E1 (P450 MT5) contains an intact N terminus and requires mitochondrial specific electron transfer proteins for activity,” Journal of Biological Chemistry, vol. 276, no. 27, pp. 24680–24689, 2001. View at Publisher · View at Google Scholar · View at Scopus
67. H. Raza, S. K. Prabu, M. A. Robin, and N. G. Avadhani, “Elevated mitochondrial cytochrome P450 2E1 and glutathione S-transferase A4-4 in streptozotocin-induced diabetic rats: tissue-specific variations and roles in Oxidative stress,” Diabetes, vol. 53, no. 1, pp. 185–194, 2004. View at Publisher · View at Google Scholar · View at Scopus
68. S. K. Mantena, A. L. King, K. K. Andringa, A. Landar, V. Darley-Usmar, and S. M. Bailey, “Novel interactions of mitochondria and reactive oxygen/nitrogen species in alcohol mediated liver disease,” World Journal of Gastroenterology, vol. 13, no. 37, pp. 4967–4973, 2007. View at Scopus
69. N. Sato, T. Kamada, and S. Kawano, “Effect of acute and chronic ethanol consumption on hepatic tissue oxygen tension in rats,” Pharmacology Biochemistry and Behavior, vol. 18, no. 1, pp. 443–447, 1983. View at Publisher · View at Google Scholar · View at Scopus
70. N. Sato, “Central role of mitochondria in metabolic regulation of liver pathophysiology,” Journal of Gastroenterology and Hepatology, vol. 22, no. 1, pp. S1–S6, 2007. View at Publisher · View at Google Scholar · View at Scopus
71. S. M. Bailey and C. C. Cunningham, “Contribution of mitochondria to oxidative stress associated with alcoholic liver disease,” Free Radical Biology and Medicine, vol. 32, no. 1, pp. 11–16, 2002. View at Publisher · View at Google Scholar · View at Scopus
72. A. Venkatraman, A. Landar, A. J. Davis et al., “Modification of the mitochondrial proteome in response to the stress of ethanol-dependent hepatotoxicity,” Journal of Biological Chemistry, vol. 279, no. 21, pp. 22092–22101, 2004. View at Publisher · View at Google Scholar · View at Scopus
73. A. Cahill, X. Wang, and J. B. Hoek, “Increased oxidative damage to mitochondrial DNA following chronic ethanol consumption,” Biochemical and Biophysical Research Communications, vol. 235, no. 2, pp. 286–290, 1997. View at Publisher · View at Google Scholar · View at Scopus
74. W. B. Coleman and C. C. Cunningham, “Effects of chronic ethanol consumption on the synthesis of polypeptides encoded by the hepatic mitochondrial genome,” Biochimica et Biophysica Acta, vol. 1019, no. 2, pp. 142–150, 1990. View at Publisher · View at Google Scholar · View at Scopus
75. T. Wang, R. V. Campbell, M. K. Yi, S. M. Lemon, and S. A. Weinman, “Role of Hepatitis C virus core protein in viral-induced mitochondrial dysfunction,” Journal of Viral Hepatitis, vol. 17, no. 11, pp. 784–793, 2010. View at Scopus
76. W. Lim, S. H. Kwon, H. Cho et al., “HBx targeting to mitochondria and ROS generation are necessary but insufficient for HBV-induced cyclooxygenase-2 expression,” Journal of Molecular Medicine, vol. 88, no. 4, pp. 359–369, 2010. View at Publisher · View at Google Scholar · View at Scopus
77. K. Begriche, J. Massart, M. A. Robin, A. Borgne-Sanchez, and B. Fromenty, “Drug-induced toxicity on mitochondria and lipid metabolism: mechanistic diversity and deleterious consequences for the liver,” Journal of Hepatology, vol. 54, no. 4, pp. 773–794, 2011. View at Publisher · View at Google Scholar · View at Scopus
78. M. T. Kuo and N. Savaraj, “Roles of reactive oxygen species in hepatocarcinogenesis and drug resistance gene expression in liver cancers,” Molecular Carcinogenesis, vol. 45, no. 9, pp. 701–709, 2006. View at Publisher · View at Google Scholar · View at Scopus
79. H. M. Shen, C. Y. Shi, Y. Shen, and C. N. Ong, “Detection of elevated reactive oxygen species level in cultured rat hepatocytes treated with aflatoxin B1,” Free Radical Biology and Medicine, vol. 21, no. 2, pp. 139–146, 1996. View at Publisher · View at Google Scholar · View at Scopus
80. P. C. Klohn, H. Massalha, and H. G. Neumann, “A metabolite of carcinogenic 2-acetylaminofluorene, 2-nitrosofluorene, induces redox cycling in mitochondria,” Biochimica et Biophysica Acta, vol. 1229, no. 3, pp. 363–372, 1995. View at Publisher · View at Google Scholar · View at Scopus
81. T. K. Macus, Z. Liu, Y. Wei et al., “Induction of human MDR1 gene expression by 2-acetylaminofluorene is mediated by effectors of the phosphoinositide 3-kinase pathway that activate NF-κB signaling,” Oncogene, vol. 21, no. 13, pp. 1945–1954, 2002. View at Publisher · View at Google Scholar · View at Scopus
82. Y. S. Bae, S. W. Kang, M. S. Seo et al., “Epidermal growth factor (EGF)-induced generation of hydrogen peroxide. Role in EGF receptor-mediated tyrosine phosphorylation,” Journal of Biological Chemistry, vol. 272, no. 1, pp. 217–221, 1997. View at Publisher · View at Google Scholar · View at Scopus
83. Y. S. Bae, J. Y. Sung, O. S. Kim et al., “Platelet-derived growth factor-induced H2O2 production requires the activation of phosphatidylinositol 3-kinase,” Journal of Biological Chemistry, vol. 275, no. 14, pp. 10527–10531, 2000. View at Publisher · View at Google Scholar · View at Scopus
84. V. M. Factor, A. Kiss, J. T. Woitach, P. J. Wirth, and S. S. Thorgeirsson, “Disruption of redox homeostasis in the transforming growth factor-α/c- myc transgenic mouse model of accelerated hepatocarcinogenesis,” Journal of Biological Chemistry, vol. 273, no. 25, pp. 15846–15853, 1998. View at Publisher · View at Google Scholar · View at Scopus
85. A. P. Rolo, J. S. Teodoro, C. Peralta, J. Rosello-Catafau, and C. M. Palmeira, “Prevention of I/R injury in fatty livers by ischemic preconditioning is associated with increased mitochondrial tolerance: the key role of ATPsynthase and mitochondrial permeability transition,” Transplant International, vol. 22, no. 11, pp. 1081–1090, 2009. View at Publisher · View at Google Scholar · View at Scopus
86. D. Pessayre, B. Fromenty, A. Berson et al., “Central role of mitochondria in drug-induced liver injury,” Drug Metabolism Reviews, vol. 44, no. 1, pp. 34–87, 2012. View at Publisher · View at Google Scholar
87. G. Serviddio, F. Bellanti, J. Sastre, G. Vendemiale, and E. Altomare, “Targeting mitochondria: a new promising approach for the treatment of liver diseases,” Current Medicinal Chemistry, vol. 17, no. 22, pp. 2325–2337, 2010. View at Publisher · View at Google Scholar · View at Scopus
88. C. Handschin, “The biology of PGC-1α and its therapeutic potential,” Trends in Pharmacological Sciences, vol. 30, no. 6, pp. 322–329, 2009. View at Publisher · View at Google Scholar · View at Scopus
89. R. C. Scarpulla, “Metabolic control of mitochondrial biogenesis through the PGC-1 family regulatory network,” Biochimica et Biophysica Acta, vol. 1813, no. 7, pp. 1269–1278, 2011. View at Publisher · View at Google Scholar · View at Scopus
90. J. C. Yoon, P. Puigserver, G. Chen et al., “Control of hepatic gluconeogenesis through the transcriptional coaotivator PGC-1,” Nature, vol. 413, no. 6852, pp. 131–138, 2001. View at Publisher · View at Google Scholar · View at Scopus
91. P. Puigserver, J. Rhee, J. Donovan et al., “Insulin-regulated hepatic gluconeogenesis through FOXO1-PGC-1α interaction,” Nature, vol. 423, no. 6939, pp. 550–555, 2003. View at Publisher · View at Google Scholar · View at Scopus
92. J. Rhee, Y. Inoue, J. C. Yoon et al., “Regulation of hepatic fasting response by PPARγ coactivator-1α (PGC-1): requirement for hepatocyte nuclear factor 4α in gluconeogenesis,” Proceedings of the National Academy of Sciences of the United States of America, vol. 100, no. 7, pp. 4012–4017, 2003. View at Publisher · View at Google Scholar · View at Scopus
93. C. Handschin, J. Lin, J. Rhee et al., “Nutritional regulation of hepatic heme biosynthesis and porphyria through PGC-1α,” Cell, vol. 122, no. 4, pp. 505–515, 2005. View at Publisher · View at Google Scholar · View at Scopus
94. J. M. Huss and D. P. Kelly, “Nuclear receptor signaling and cardiac energetics,” Circulation Research, vol. 95, no. 6, pp. 568–578, 2004. View at Publisher · View at Google Scholar · View at Scopus
95. S. Song, R. R. Attia, S. Connaughton et al., “Peroxisome proliferator activated receptor α (PPARα) and PPAR gamma coactivator (PGC-1α) induce carnitine palmitoyltransferase IA (CPT-1A) via independent gene elements,” Molecular and Cellular Endocrinology, vol. 325, no. 1-2, pp. 54–63, 2010. View at Publisher · View at Google Scholar · View at Scopus
96. Y. Lustig, J. L. Ruas, J. L. Estall et al., “Separation of the gluconeogenic and mitochondrial functions of pgc-1α through s6 kinase,” Genes and Development, vol. 25, no. 12, pp. 1232–1244, 2011. View at Publisher · View at Google Scholar · View at Scopus
97. L. F. Yu, B. Y. Qiu, F. J. Nan, and J. Li, “AMPK activators as novel therapeutics for type 2 diabetes,” Current Topics in Medicinal Chemistry, vol. 10, no. 4, pp. 397–410, 2010. View at Publisher · View at Google Scholar · View at Scopus
98. S. Jäger, C. Handschin, J. St-Pierre, and B. M. Spiegelman, “AMP-activated protein kinase (AMPK) action in skeletal muscle via direct phosphorylation of PGC-1α,” Proceedings of the National Academy of Sciences of the United States of America, vol. 104, no. 29, pp. 12017–12022, 2007. View at Publisher · View at Google Scholar · View at Scopus
99. A. Shlomai, N. Paran, and Y. Shaul, “PGC-1α controls hepatitis B virus through nutritional signals,” Proceedings of the National Academy of Sciences of the United States of America, vol. 103, no. 43, pp. 16003–16008, 2006. View at Publisher · View at Google Scholar · View at Scopus
100. L. C. Gomes, G. D. Benedetto, and L. Scorrano, “During autophagy mitochondria elongate, are spared from degradation and sustain cell viability,” Nature Cell Biology, vol. 13, no. 5, pp. 589–598, 2011. View at Publisher · View at Google Scholar · View at Scopus
101. C. Mitchell, M. A. Robin, A. Mayeuf et al., “Protection against hepatocyte mitochondrial dysfunction delays fibrosis progression in mice,” American Journal of Pathology, vol. 175, no. 5, pp. 1929–1937, 2009. View at Publisher · View at Google Scholar · View at Scopus
102. H. Yadav, C. Quijano, A. K. Kamaraju et al., “Protection from obesity and diabetes by blockade of TGF-β/Smad3 signaling,” Cell Metabolism, vol. 14, no. 1, pp. 67–79, 2011. View at Publisher · View at Google Scholar · View at Scopus
103. D. W. Hailey, A. S. Rambold, P. Satpute-Krishnan et al., “Mitochondria supply membranes for autophagosome biogenesis during starvation,” Cell, vol. 141, no. 4, pp. 656–667, 2010. View at Publisher · View at Google Scholar · View at Scopus
104. C. He and D. J. Klionsky, “Regulation mechanisms and signaling pathways of autophagy,” Annual Review of Genetics, vol. 43, pp. 67–93, 2009. View at Publisher · View at Google Scholar · View at Scopus
105. G. Kroemer, G. Mariño, and B. Levine, “Autophagy and the integrated stress response,” Molecular Cell, vol. 40, no. 2, pp. 280–293, 2010. View at Publisher · View at Google Scholar · View at Scopus
106. R. J. Youle and D. P. Narendra, “Mechanisms of mitophagy,” Nature Reviews Molecular Cell Biology, vol. 12, no. 1, pp. 9–14, 2011. View at Publisher · View at Google Scholar · View at Scopus
107. R. A. Gottlieb and R. M. Mentzer, “Autophagy during cardiac stress: joys and frustrations of autophagy,” Annual Review of Physiology, vol. 72, pp. 45–59, 2009. View at Publisher · View at Google Scholar · View at Scopus
108. D. Chen, F. Gao, B. Li et al., “Parkin mono-ubiquitinates Bcl-2 and regulates autophagy,” Journal of Biological Chemistry, vol. 285, no. 49, pp. 38214–38223, 2010. View at Publisher · View at Google Scholar · View at Scopus
109. J. Y. Lee, Y. Nagano, J. P. Taylor, K. L. Lim, and T. P. Yao, “Disease-causing mutations in Parkin impair mitochondrial ubiquitination, aggregation, and HDAC6-dependent mitophagy,” Journal of Cell Biology, vol. 189, no. 4, pp. 671–679, 2010. View at Publisher · View at Google Scholar · View at Scopus
110. M. d'Amora, C. Angelini, M. Marcoli, C. Cervetto, T. Kitada, and M. Vallarino, “Expression of PINK1 in the brain, eye and ear of mouse during embryonic development,” Journal of Chemical Neuroanatomy, vol. 41, no. 2, pp. 73–85, 2011. View at Publisher · View at Google Scholar · View at Scopus
111. D. F. Egan, D. B. Shackelford, M. M. Mihaylova et al., “Phosphorylation of ULK1 (hATG1) by AMP-activated protein kinase connects energy sensing to mitophagy,” Science, vol. 331, no. 6016, pp. 456–461, 2011. View at Publisher · View at Google Scholar · View at Scopus
112. I. Kim and J. J. Lemasters, “Mitochondrial degradation by autophagy (mitophagy) in GFP-LC3 transgenic hepatocytes during nutrient deprivation,” American Journal of Physiology, vol. 300, no. 2, pp. C308–C317, 2011. View at Publisher · View at Google Scholar · View at Scopus
113. Y. Cheng, M. Zhou, C. H. Tung, M. Ji, and F. Zhang, “Studies on two types of PTP1B inhibitors for the treatment of type 2 diabetes: hologram QSAR for OBA and BBB analogues,” Bioorganic and Medicinal Chemistry Letters, vol. 20, no. 11, pp. 3329–3337, 2010. View at Publisher · View at Google Scholar · View at Scopus
114. S. Gottschalk, C. Zwingmann, V.-A. Raymond, M. C. Hohnholt, T. S. Chan, and M. Bilodeau, “Hepatocellular apoptosis in mice is associated with early upregulation of mitochondrial glucose metabolism,” Apoptosis, vol. 17, no. 2, pp. 143–153, 2012. View at Publisher · View at Google Scholar
115. C. Poussin, M. Ibberson, D. Hall et al., “Oxidative phosphorylation flexibility in the liver of mice resistant to high-fat diet-induced hepatic steatosis,” Diabetes, vol. 60, no. 9, pp. 2216–2224, 2011. View at Publisher · View at Google Scholar
116. J. Albrecht and M. D. Norenberg, “Glutamine: a Trojan horse in ammonia neurotoxicity,” Hepatology, vol. 44, no. 4, pp. 788–794, 2006. View at Publisher · View at Google Scholar · View at Scopus
117. M. D. Norenberg, K. V. Rama Rao, and A. R. Jayakumar, “Mechanisms of ammonia-induced astrocyte swelling,” Metabolic Brain Disease, vol. 20, no. 4, pp. 303–318, 2005. View at Publisher · View at Google Scholar · View at Scopus
118. S. Ahmad, C. W. White, L. Y. Chang, B. K. Schneider, and C. B. Allen, “Glutamine protects mitochondrial structure and function in oxygen toxicity,” American Journal of Physiology, vol. 280, no. 4, pp. L779–L791, 2001. View at Scopus
119. C. H. Eng and R. T. Abraham, “Glutaminolysis yields a metabolic by-product that stimulates autophagy,” Autophagy, vol. 6, no. 7, pp. 968–970, 2010. View at Publisher · View at Google Scholar · View at Scopus
120. I. Nissim, O. Horyn, I. Nissim et al., “Down-regulation of Hepatic Urea Synthesis by Oxypurines: xanthine and uric acid inhibit N-acetylglutamate synthase,” Journal of Biological Chemistry, vol. 286, no. 25, pp. 22055–22068, 2011. View at Publisher · View at Google Scholar · View at Scopus
121. D. Han, F. Antunes, R. Canali, D. Rettori, and E. Cadenas, “Voltage-dependent anion channels control the release of the superoxide anion from mitochondria to cytosol,” Journal of Biological Chemistry, vol. 278, no. 8, pp. 5557–5563, 2003. View at Publisher · View at Google Scholar · View at Scopus
122. H. L. Pahl, “Activators and target genes of Rel/NF-κB transcription factors,” Oncogene, vol. 18, no. 49, pp. 6853–6866, 1999. View at Scopus
123. C. A. Piantadosi and H. B. Suliman, “Mitochondrial transcription factor A induction by redox activation of nuclear respiratory factor 1,” Journal of Biological Chemistry, vol. 281, no. 1, pp. 324–333, 2006. View at Publisher · View at Google Scholar · View at Scopus
124. L. Chen, M. Kwong, R. Lu et al., “Nrf1 is critical for redox balance and survival of liver cells during development,” Molecular and Cellular Biology, vol. 23, no. 13, pp. 4673–4686, 2003. View at Publisher · View at Google Scholar · View at Scopus
125. T. Luedde and R. F. Schwabe, “NF-κB in the liver-linking injury, fibrosis and hepatocellular carcinoma,” Nature Reviews Gastroenterology and Hepatology, vol. 8, no. 2, pp. 108–118, 2011. View at Publisher · View at Google Scholar · View at Scopus
126. F. Wang, S. Kaur, L. G. Cavin, and M. Arsura, “Nuclear-factor-κB (NF-κB) and radical oxygen species play contrary roles in transforming growth factor-β1 (TGF-β1)-induced apoptosis in hepatocellular carcinoma (HCC) cells,” Biochemical and Biophysical Research Communications, vol. 377, no. 4, pp. 1107–1112, 2008. View at Publisher · View at Google Scholar · View at Scopus
127. N. S. Chandel, D. S. McClintock, C. E. Feliciano et al., “Reactive oxygen species generated at mitochondrial Complex III stabilize hypoxia-inducible factor-1α during hypoxia: a mechanism of O2 sensing,” Journal of Biological Chemistry, vol. 275, no. 33, pp. 25130–25138, 2000. View at Publisher · View at Google Scholar · View at Scopus
128. L. A. Dada, N. S. Chandel, K. M. Ridge, C. Pedemonte, A. M. Bertorello, and J. I. Sznajder, “Hypoxia-induced endocytosis, of Na,K-ATPase in alveolar epithelial cells is mediated by mitochondrial reactive oxygen species and PKC-ζ,” Journal of Clinical Investigation, vol. 111, no. 7, pp. 1057–1064, 2003. View at Publisher · View at Google Scholar · View at Scopus
129. L. Liu, T. P. Cash, R. G. Jones, B. Keith, C. B. Thompson, and M. C. Simon, “Hypoxia-induced energy stress regulates mRNA translation and cell growth,” Molecular Cell, vol. 21, no. 4, pp. 521–531, 2006. View at Publisher · View at Google Scholar · View at Scopus
130. M. Marí, A. Morales, A. Colell, C. García-Ruiz, and J. C. Fernández-Checa, “Mitochondrial glutathione, a key survival antioxidant,” Antioxidants and Redox Signaling, vol. 11, no. 11, pp. 2685–2700, 2009. View at Publisher · View at Google Scholar · View at Scopus
131. J. M. Lluis, F. Buricchi, P. Chiarugi, A. Morales, and J. C. Fernandez-Checa, “Dual role of mitochondrial reactive oxygen species in hypoxia signaling: activation of nuclear factor-KB via c-SRC- and oxidant-dependent cell death,” Cancer Research, vol. 67, no. 15, pp. 7368–7377, 2007. View at Publisher · View at Google Scholar · View at Scopus
132. O. Coll, A. Colell, C. García-Ruiz, N. Kaplowitz, and J. C. Fernández-Checa, “Sensitivity of the 2-oxoglutarate carrier to alcohol intake contributes to mitochondrial glutathione depletion,” Hepatology, vol. 38, no. 3, pp. 692–702, 2003. View at Publisher · View at Google Scholar · View at Scopus
133. M. Marí, F. Caballero, A. Colell et al., “Mitochondrial free cholesterol loading sensitizes to TNF- and Fas-mediated steatohepatitis,” Cell Metabolism, vol. 4, no. 3, pp. 185–198, 2006. View at Publisher · View at Google Scholar · View at Scopus
134. S. Krahenbuhl, J. Stucki, and J. Reichen, “Reduced activity of the electron transport chain in liver mitochondria isolated from rats with secondary biliary cirrhosis,” Hepatology, vol. 15, no. 6, pp. 1160–1166, 1992. View at Publisher · View at Google Scholar · View at Scopus
135. S. Krahenbuhl, C. Talos, B. H. Lauterburg, and J. Reichen, “Reduced antioxidative capacity in liver mitochondria from bile duct ligated rats,” Hepatology, vol. 22, no. 2, pp. 607–612, 1995. View at Scopus
136. D. Herranz, M. Muñoz-Martin, M. Cañamero et al., “Sirt1 improves healthy ageing and protects from metabolic syndrome-associated cancer,” Nature Communications, vol. 1, no. 1, 2010. View at Publisher · View at Google Scholar
137. L. Guarente, “Sirtuins, aging, and medicine,” New England Journal of Medicine, vol. 364, no. 23, pp. 2235–2244, 2011. View at Publisher · View at Google Scholar · View at Scopus
138. N. Nasrin, X. Wu, E. Fortier et al., “SIRT4 regulates fatty acid oxidation and mitochondrial gene expression in liver and muscle cells,” Journal of Biological Chemistry, vol. 285, no. 42, pp. 31995–32002, 2010. View at Publisher · View at Google Scholar · View at Scopus
139. T. Nakagawa, D. J. Lomb, M. C. Haigis, and L. Guarente, “SIRT5 deacetylates carbamoyl phosphate synthetase 1 and regulates the urea cycle,” Cell, vol. 137, no. 3, pp. 560–570, 2009. View at Publisher · View at Google Scholar · View at Scopus
140. B. H. Ahn, H. S. Kim, S. Song et al., “A role for the mitochondrial deacetylase Sirt3 in regulating energy homeostasis,” Proceedings of the National Academy of Sciences of the United States of America, vol. 105, no. 38, pp. 14447–14452, 2008. View at Publisher · View at Google Scholar · View at Scopus
141. X. Qiu, K. Brown, M. D. Hirschey, E. Verdin, and D. Chen, “Calorie restriction reduces oxidative stress by SIRT3-mediated SOD2 activation,” Cell Metabolism, vol. 12, no. 6, pp. 662–667, 2010. View at Publisher · View at Google Scholar · View at Scopus
142. R. Tao, M. C. Coleman, J. D. Pennington et al., “Sirt3-mediated deacetylation of evolutionarily conserved lysine 122 regulates MnSOD activity in response to stress,” Molecular Cell, vol. 40, no. 6, pp. 893–904, 2010. View at Publisher · View at Google Scholar · View at Scopus
143. S. Someya, W. Yu, W. C. Hallows et al., “Sirt3 mediates reduction of oxidative damage and prevention of age-related hearing loss under Caloric Restriction,” Cell, vol. 143, no. 5, pp. 802–812, 2010. View at Publisher · View at Google Scholar · View at Scopus
144. J. Chen, B. Zhang, N. Wong et al., “Sirtuin 1 is upregulated in a subset of hepatocellular carcinomas where it is essential for telomere maintenance and tumor cell growth,” Cancer Research, vol. 71, no. 12, pp. 4138–4149, 2011. View at Publisher · View at Google Scholar · View at Scopus
145. H. N. Choi, J. S. Bae, U. Jamiyandorj et al., “Expression and role of SIRT1 in hepatocellular carcinoma,” Oncology Reports, vol. 26, no. 2, pp. 503–510, 2011. View at Publisher · View at Google Scholar · View at Scopus
146. J. T. Rodgers, C. Lerin, W. Haas, S. P. Gygi, B. M. Spiegelman, and P. Puigserver, “Nutrient control of glucose homeostasis through a complex of PGC-1α and SIRT1,” Nature, vol. 434, no. 7029, pp. 113–118, 2005. View at Publisher · View at Google Scholar · View at Scopus
147. X. Hou, S. Xu, K. A. Maitland-Toolan et al., “SIRT1 regulates hepatocyte lipid metabolism through activating AMP-activated protein kinase,” Journal of Biological Chemistry, vol. 283, no. 29, pp. 20015–20026, 2008. View at Publisher · View at Google Scholar · View at Scopus
148. M. D. Hirschey, T. Shimazu, E. Goetzman et al., “SIRT3 regulates mitochondrial fatty-acid oxidation by reversible enzyme deacetylation,” Nature, vol. 464, no. 7285, pp. 121–125, 2010. View at Publisher · View at Google Scholar · View at Scopus
149. A. A. Kendrick, M. Choudhury, S. M. Rahman et al., “Fatty liver is associated with reduced SIRT3 activity and mitochondrial protein hyperacetylation,” Biochemical Journal, vol. 433, no. 3, pp. 505–514, 2011. View at Publisher · View at Google Scholar · View at Scopus
150. S. Michel, A. Wanet, A. De Pauw, G. Rommelaere, T. Arnould, and P. Renard, “Crosstalk between mitochondrial (dys)function and mitochondrial abundance,” Journal of Cellular Physiology, vol. 227, no. 6, pp. 2297–2310, 2012. View at Publisher · View at Google Scholar